# Application

```{eval-rst}

.. automodule:: torii_usb.usb.usb3.application
	:members:

```

## Descriptor

```{eval-rst}

.. automodule:: torii_usb.usb.usb3.application.descriptor
	:members:

```

## Request

```{eval-rst}

.. automodule:: torii_usb.usb.usb3.application.request
	:members:

```
